@@ -102,7 +102,6 @@ func GetCommands() *core.Commands {
 	cmds.MustFind("instance", "image", "delete").Override(imageDeleteBuilder)
 	cmds.Merge(core.NewCommands(
 		imageWaitCommand(),
-		imageUpdateCommand(),
 	))
 
 	//
@@ -112,9 +111,9 @@ func GetCommands() *core.Commands {
 
 	cmds.MustFind("instance", "snapshot", "create").Override(snapshotCreateBuilder)
 	cmds.MustFind("instance", "snapshot", "list").Override(snapshotListBuilder)
+	cmds.MustFind("instance", "snapshot", "update").Override(snapshotUpdateBuilder)
 	cmds.Merge(core.NewCommands(
 		snapshotWaitCommand(),
-		snapshotUpdateCommand(),
 	))
 
 	//
@@ -150,7 +149,6 @@ func GetCommands() *core.Commands {
 
 	cmds.Merge(core.NewCommands(
 		securityGroupClearCommand(),
-		securityGroupUpdateCommand(),
 		securityGroupEditCommand(),
 	))
 
