@@ -294,82 +294,6 @@ func imageDeleteBuilder(c *core.Command) *core.Command {
 // Commands
 //
 
-func imageUpdateCommand() *core.Command {
-	return &core.Command{
-		Short:     `Update an instance image`,
-		Long:      `Update properties of an instance image.`,
-		Namespace: "instance",
-		Resource:  "image",
-		Verb:      "update",
-		ArgsType:  reflect.TypeOf(instance.UpdateImageRequest{}),
-		ArgSpecs: core.ArgSpecs{
-			{
-				Name:       "image-id",
-				Required:   true,
-				Positional: true,
-			},
-			{
-				Name:       "name",
-				Required:   false,
-				Positional: false,
-			},
-			{
-				Name:       "arch",
-				Required:   false,
-				Positional: false,
-				EnumValues: []string{"x86_64", "arm"},
-			},
-			{
-				Name:       "extra-volumes.{index}.id",
-				Short:      `Additional extra-volume ID`,
-				Required:   false,
-				Deprecated: false,
-				Positional: false,
-			},
-			{
-				Name:       "from-server",
-				Required:   false,
-				Positional: false,
-			},
-			{
-				Name:       "public",
-				Required:   false,
-				Positional: false,
-			},
-			{
-				Name:       "tags.{index}",
-				Required:   false,
-				Positional: false,
-			},
-			core.ProjectArgSpec(),
-			core.OrganizationArgSpec(),
-			core.ZoneArgSpec(scw.ZoneFrPar1, scw.ZoneFrPar2, scw.ZoneFrPar3, scw.ZoneNlAms1, scw.ZoneNlAms2, scw.ZonePlWaw1),
-		},
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
-			request := argsI.(*instance.UpdateImageRequest)
-
-			client := core.ExtractClient(ctx)
-			api := instance.NewAPI(client)
-
-			return api.UpdateImage(request)
-		},
-		Examples: []*core.Example{
-			{
-				Short: "Update image name",
-				Raw:   "scw instance image update image-id=11111111-1111-1111-1111-111111111111 name=foo",
-			},
-			{
-				Short: "Update image public",
-				Raw:   "scw instance image update image-id=11111111-1111-1111-1111-111111111111 public=true",
-			},
-			{
-				Short: "Add extra volume",
-				Raw:   "scw instance image update image-id=11111111-1111-1111-1111-111111111111 extra-volumes.1.id=11111111-1111-1111-1111-111111111111",
-			},
-		},
-	}
-}
-
 func imageWaitCommand() *core.Command {
 	return &core.Command{
 		Short:     `Wait for image to reach a stable state`,
