@@ -727,7 +727,7 @@ func sanitizeVolumeMap(serverName string, volumes map[string]*instance.VolumeSer
 // Caching listImage response for shell completion
 var completeListImagesCache *marketplace.ListImagesResponse
 
-func instanceServerCreateImageAutoCompleteFunc(ctx context.Context, prefix string) core.AutocompleteSuggestions {
+func instanceServerCreateImageAutoCompleteFunc(ctx context.Context, prefix string, _ any) core.AutocompleteSuggestions {
 	suggestions := core.AutocompleteSuggestions(nil)
 
 	client := core.ExtractClient(ctx)
@@ -778,8 +778,12 @@ func instanceServerCreateIPCreate(args *instanceCreateServerRequest, api *instan
 		Organization: args.OrganizationID,
 	}
 
-	if args.RoutedIPEnabled != nil && *args.RoutedIPEnabled {
-		req.Type = instance.IPTypeRoutedIPv4
+	if args.RoutedIPEnabled != nil {
+		if *args.RoutedIPEnabled {
+			req.Type = instance.IPTypeRoutedIPv4
+		} else {
+			req.Type = instance.IPTypeNat
+		}
 	}
 
 	res, err := api.CreateIP(req)
