@@ -1,8 +1,10 @@
-package k8s
+package k8s_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 )
 
@@ -11,7 +13,7 @@ func Test_GetVersion(t *testing.T) {
 	// Simple use cases
 	////
 	t.Run("simple", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: k8s.GetCommands(),
 		Cmd:      "scw k8s version get " + kapsuleVersion,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -22,7 +24,7 @@ func Test_GetVersion(t *testing.T) {
 
 func Test_ListVersion_Basic(t *testing.T) {
 	t.Run("simple", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: k8s.GetCommands(),
 		Cmd:      "scw k8s version list",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
