@@ -5,6 +5,7 @@ package wasm
 import (
 	"bytes"
 	"io"
+	"net/http"
 
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces"
@@ -47,6 +48,9 @@ func runCommand(buildInfo *core.BuildInfo, cfg *RunConfig, args []string, stdout
 			DefaultOrganizationID: cfg.DefaultOrganizationID,
 			APIUrl:                cfg.APIUrl,
 		},
+		HTTPClient: &http.Client{
+			Transport: &Transport{},
+		},
 	})
 
 	return exitCode
